@@ -78,7 +78,8 @@ print.slendr_model <- function(x, ...) {
     cat("[no geneflow]\n")
   cat("generation time:", x$generation_time, "\n")
   cat("time direction:", x$direction, "\n")
-  cat("total running length:", x$orig_length, "model time units\n")
+  cat("time units:", x$time_units, "\n")
+  cat("total running length:", x$orig_length, "time units\n")
 
   cat("model type: ")
   if (inherits(x$world, "slendr_map")) {
@@ -86,12 +87,15 @@ print.slendr_model <- function(x, ...) {
     cat("  - number of spatial maps:", nrow(x$maps), "\n")
     cat("  - resolution:", x$resolution, "distance units per pixel\n\n")
   } else
-    cat("non-spatial\n\n")
+    cat("non-spatial\n")
+
+  if (x$customized)
+    cat("model contains a user-defined SLiM customization\n")
 
   if (is.null(x$path))
-    cat("non-serialized slendr model\n")
+    cat("\nnon-serialized slendr model\n")
   else
-    cat("configuration files in:", normalizePath(x$path), "\n")
+    cat("\nconfiguration files in:", normalizePath(x$path, mustWork = FALSE), "\n")
 }
 
 
