@@ -1,5 +1,7 @@
 skip_if(!is_slendr_env_present())
 
+init_env(quiet = TRUE)
+
 seed <- 42 # random seed
 seq_len <- 2e5 # amount of sequence to simulate
 rec_rate <- 1e-8 # uniform recombination rate
@@ -25,14 +27,14 @@ forward_samples <- rbind(
   schedule_sampling(forward_model, times = c(2000, 2050, 1123), list(a, 1), list(b, 1), list(x1, 10), list(x2, 10), list(c, 1), list(o, 1))
 )
 
-ts_forward_slim <- tempfile(fileext = ".trees")
-ts_forward_msprime <- tempfile(fileext = ".trees")
+ts_forward_slim <- normalizePath(tempfile(fileext = ".trees"), winslash = "/", mustWork = FALSE)
+ts_forward_msprime <- normalizePath(tempfile(fileext = ".trees"), winslash = "/", mustWork = FALSE)
 
-slim(forward_model, sequence_length = seq_len, recombination_rate = rec_rate, output = ts_forward_slim, samples = forward_samples, random_seed = seed)
-msprime(forward_model, sequence_length = seq_len, recombination_rate = rec_rate, output = ts_forward_msprime, samples = forward_samples, random_seed = seed)
+slim(forward_model, sequence_length = seq_len, recombination_rate = rec_rate, samples = forward_samples, random_seed = seed) %>% ts_write(ts_forward_slim)
+msprime(forward_model, sequence_length = seq_len, recombination_rate = rec_rate, samples = forward_samples, random_seed = seed) %>% ts_write(ts_forward_msprime)
 
-forward_sts <- ts_load(model = forward_model, file = ts_forward_slim)
-forward_mts <- ts_load(model = forward_model, file = ts_forward_msprime)
+forward_sts <- ts_read(model = forward_model, file = ts_forward_slim)
+forward_mts <- ts_read(model = forward_model, file = ts_forward_msprime)
 
 test_that("msprime and SLiM metadata is exactly the same (forward model)", {
   fields <- c("version", "description", "sampling")
@@ -40,7 +42,7 @@ test_that("msprime and SLiM metadata is exactly the same (forward model)", {
   m_meta <- ts_metadata(forward_mts)[fields]
   expect_true(all(sapply(fields, function(f) all(s_meta[[f]] == m_meta[[f]]))))
 
-  args <- c("RECOMB_RATE", "SEED", "SEQUENCE_LENGTH", "SIMULATION_LENGTH")
+  args <- c("RECOMBINATION_RATE", "SEED", "SEQUENCE_LENGTH", "SIMULATION_LENGTH")
   s_args <- ts_metadata(forward_sts)$arguments[args]
   m_args <- ts_metadata(forward_mts)$arguments[args]
   expect_true(all(sapply(args, function(f) all(s_args[[f]] == m_args[[f]]))))
@@ -50,13 +52,13 @@ test_that("msprime and SLiM sampling tables are exactly the same (forward model)
   expect_true(all(ts_samples(forward_sts) == ts_samples(forward_mts)))
 })
 
-test_that("sampling more individuals than is the current N triggers warning (forward model)", {
-  forward_samples <- schedule_sampling(forward_model, times = c(2000, 2050, 1123), list(a, 1), list(x1, 1000), list(x2, 1000))
-  expect_warning(
-    slim(forward_model, sequence_length = seq_len, recombination_rate = rec_rate, samples = forward_samples, random_seed = seed),
-    "There were some warnings during the simulation run"
-  )
-})
+# test_that("sampling more individuals than is the current N triggers warning (forward model)", {
+#   forward_samples <- schedule_sampling(forward_model, times = c(2000, 2050, 1123), list(a, 1), list(x1, 1000), list(x2, 1000))
+#   expect_warning(
+#     slim(forward_model, sequence_length = seq_len, recombination_rate = rec_rate, samples = forward_samples, random_seed = seed),
+#     "There were some warnings during the simulation run"
+#   )
+# })
 
 # backward models ---------------------------------------------------------
 
@@ -86,14 +88,14 @@ backward_samples <- rbind(
   schedule_sampling(backward_model, times = c(123, 250, 1000), list(a, 1), list(b, 1), list(x1, 10), list(x2, 10), list(c, 1), list(o, 1))
 )
 
-ts_backward_slim <- tempfile(fileext = ".trees")
-ts_backward_msprime <- tempfile(fileext = ".trees")
+ts_backward_slim <- normalizePath(tempfile(fileext = ".trees"), winslash = "/", mustWork = FALSE)
+ts_backward_msprime <- normalizePath(tempfile(fileext = ".trees"), winslash = "/", mustWork = FALSE)
 
-slim(backward_model, output = ts_backward_slim, sequence_length = seq_len, recombination_rate = rec_rate, samples = backward_samples, random_seed = seed)
-msprime(backward_model, output = ts_backward_msprime, sequence_length = seq_len, recombination_rate = rec_rate, samples = backward_samples, random_seed = seed)
+slim(backward_model, sequence_length = seq_len, recombination_rate = rec_rate, samples = backward_samples, random_seed = seed) %>% ts_write(ts_backward_slim)
+msprime(backward_model, sequence_length = seq_len, recombination_rate = rec_rate, samples = backward_samples, random_seed = seed) %>% ts_write(ts_backward_msprime)
 
-backward_sts <- ts_load(model = backward_model, file = ts_backward_slim)
-backward_mts <- ts_load(model = backward_model, file = ts_backward_msprime)
+backward_sts <- ts_read(model = backward_model, file = ts_backward_slim)
+backward_mts <- ts_read(model = backward_model, file = ts_backward_msprime)
 
 test_that("msprime and SLiM metadata is exactly the same (backward model)", {
   fields <- c("version", "description", "sampling")
@@ -101,7 +103,7 @@ test_that("msprime and SLiM metadata is exactly the same (backward model)", {
   m_meta <- ts_metadata(backward_mts)[fields]
   expect_true(all(sapply(fields, function(f) all(s_meta[[f]] == m_meta[[f]]))))
 
-  args <- c("RECOMB_RATE", "SEED", "SEQUENCE_LENGTH", "SIMULATION_LENGTH")
+  args <- c("RECOMBINATION_RATE", "SEED", "SEQUENCE_LENGTH", "SIMULATION_LENGTH")
   s_args <- ts_metadata(backward_sts)$arguments[args]
   m_args <- ts_metadata(backward_mts)$arguments[args]
   expect_true(all(sapply(args, function(f) all(s_args[[f]] == m_args[[f]]))))
@@ -111,10 +113,10 @@ test_that("msprime and SLiM sampling tables are exactly the same (backward model
   expect_true(all(ts_samples(backward_sts) == ts_samples(backward_mts)))
 })
 
-test_that("sampling more individuals than is the current N triggers warning (backward model)", {
-  backward_samples <- schedule_sampling(backward_model, times = c(123, 250, 1000), list(a, 1000), list(x1, 10), list(x2, 10), list(c, 1000))
-  expect_warning(
-    slim(backward_model, sequence_length = seq_len, recombination_rate = rec_rate, samples = backward_samples, random_seed = seed),
-    "There were some warnings during the simulation run"
-  )
-})
+# test_that("sampling more individuals than is the current N triggers warning (backward model)", {
+#   backward_samples <- schedule_sampling(backward_model, times = c(123, 250, 1000), list(a, 1000), list(x1, 10), list(x2, 10), list(c, 1000))
+#   expect_warning(
+#     slim(backward_model, sequence_length = seq_len, recombination_rate = rec_rate, samples = backward_samples, random_seed = seed),
+#     "There were some warnings during the simulation run"
+#   )
+# })
