@@ -26,41 +26,45 @@ samples <- rbind(
   schedule_sampling(model, times = 300, list(p1, 10), list(p2, 10))
 )
 
-slim_ts <- tempfile(fileext = ".trees")
-msprime_ts <- tempfile(fileext = ".trees")
+slim_ts <- normalizePath(tempfile(fileext = ".trees"), winslash = "/", mustWork = FALSE)
+msprime_ts <- normalizePath(tempfile(fileext = ".trees"), winslash = "/", mustWork = FALSE)
 
-locations_file <- tempfile(fileext = ".gz")
+locations_file <- normalizePath(tempfile(fileext = ".gz"), winslash = "/", mustWork = FALSE)
 
-slim(model, sequence_length = 100000, recombination_rate = 0, output = slim_ts,
+slim(model, sequence_length = 100000, recombination_rate = 0,
      locations = locations_file, burnin = 0,
      method = "batch", random_seed = 314159,
-     samples = samples, verbose = FALSE, load = FALSE)
+     samples = samples, verbose = FALSE) %>% ts_write(slim_ts)
 
-msprime(model, sequence_length = 100000, recombination_rate = 0, output = msprime_ts,
-        random_seed = 314159, samples = samples, verbose = FALSE, load = FALSE)
+msprime(model, sequence_length = 100000, recombination_rate = 0,
+        random_seed = 314159, samples = samples, verbose = FALSE) %>% ts_write(msprime_ts)
 
-test_that("ts_load generates an object of the correct type (SLiM)", {
-  ts <- ts_load(model, file = slim_ts) %>% ts_recapitate(Ne = 1, recombination_rate = 0) %>% ts_simplify()
+test_that("ts_read fails gracefully on incorrect filename", {
+  expect_error(ts <- ts_read(model, file = paste0(msprime_ts, "blah")), "File not found")
+})
+
+test_that("ts_read generates an object of the correct type (SLiM)", {
+  ts <- ts_read(model, file = slim_ts) %>% ts_recapitate(Ne = 1, recombination_rate = 0) %>% ts_simplify()
   expect_true(inherits(ts, "tskit.trees.TreeSequence"))
 })
 
 test_that("unnecessary recapitation is prevented (msprime)", {
   expect_warning(
-    ts_load(model, file = msprime_ts) %>% ts_recapitate(Ne = 1, recombination_rate = 0),
+    ts_read(model, file = msprime_ts) %>% ts_recapitate(Ne = 1, recombination_rate = 0),
     "There is no need to recapitate"
   )
 })
 
-test_that("ts_load generates an object of the correct type (msprime)", {
-  ts <- ts_load(model, file = msprime_ts)
+test_that("ts_read generates an object of the correct type (msprime)", {
+  ts <- ts_read(model, file = msprime_ts)
   expect_true(inherits(ts, "tskit.trees.TreeSequence"))
 })
 
-test_that("ts_save and ts_load result in the same tree sequence (SLiM)", {
-  ts1 <- ts_load(model, file = slim_ts)
+test_that("ts_write and ts_read result in the same tree sequence (SLiM)", {
+  ts1 <- ts_read(model, file = slim_ts)
   file <- paste0(tempfile(), "_slim.trees")
-  ts_save(ts1, file)
-  ts2 <- ts_load(model, file = file)
+  ts_write(ts1, file)
+  ts2 <- ts_read(model, file = file)
 
   data1 <- ts_nodes(ts1); data2 <- ts_nodes(ts2)
   samples1 <- ts_samples(ts1); samples2 <- ts_samples(ts2)
@@ -69,11 +73,11 @@ test_that("ts_save and ts_load result in the same tree sequence (SLiM)", {
   expect_equal(samples1, samples2)
 })
 
-test_that("ts_save and ts_load result in the same tree sequence (msprime)", {
-  ts1 <- ts_load(model, file = msprime_ts)
+test_that("ts_write and ts_read result in the same tree sequence (msprime)", {
+  ts1 <- ts_read(model, file = msprime_ts)
   file <- paste0(tempfile(), "_msprime.trees")
-  ts_save(ts1, file)
-  ts2 <- ts_load(model, file = file)
+  ts_write(ts1, file)
+  ts2 <- ts_read(model, file = file)
 
   data1 <- ts_nodes(ts1); data2 <- ts_nodes(ts2)
   samples1 <- ts_samples(ts1); samples2 <- ts_samples(ts2)
@@ -83,7 +87,7 @@ test_that("ts_save and ts_load result in the same tree sequence (msprime)", {
 })
 
 test_that("tree sequence contains the right number of sampled individuals (SLiM)", {
-  ts <- ts_load(model, file = slim_ts) %>% ts_recapitate(Ne = 1, recombination_rate = 0) %>%
+  ts <- ts_read(model, file = slim_ts) %>% ts_recapitate(Ne = 1, recombination_rate = 0) %>%
     ts_simplify()
   counts <- ts_nodes(ts) %>%
     dplyr::filter(sampled) %>%
@@ -94,7 +98,7 @@ test_that("tree sequence contains the right number of sampled individuals (SLiM)
 })
 
 test_that("locations and times in the tree sequence match values saved by SLiM", {
-  ts <- ts_load(model, file = slim_ts) %>% ts_recapitate(Ne = 1, recombination_rate = 0) %>% ts_simplify()
+  ts <- ts_read(model, file = slim_ts) %>% ts_recapitate(Ne = 1, recombination_rate = 0) %>% ts_simplify()
   individuals <- ts_nodes(ts) %>% dplyr::filter(sampled) %>% dplyr::distinct(ind_id, .keep_all = TRUE)
   true_locations <- readr::read_tsv(locations_file, col_types = "iicidd") %>%
     dplyr::mutate(time = convert_slim_time(gen, model))
@@ -111,16 +115,16 @@ test_that("locations and times in the tree sequence match values saved by SLiM",
 })
 
 test_that("extracted individual, node, edge, and mutation counts match the tree sequence (SLiM)", {
-  ts1 <- ts_load(model, file = slim_ts)
+  ts1 <- ts_read(model, file = slim_ts)
   table1 <- ts_nodes(ts1)
 
-  ts2 <- ts_load(model, file = slim_ts) %>% ts_recapitate(Ne = 1000, recombination_rate = 0)
+  ts2 <- ts_read(model, file = slim_ts) %>% ts_recapitate(Ne = 1000, recombination_rate = 0)
   table2 <- ts_nodes(ts2)
 
-  ts3 <- ts_load(model, file = slim_ts) %>% ts_recapitate(Ne = 1000, recombination_rate = 0) %>% ts_simplify()
+  ts3 <- ts_read(model, file = slim_ts) %>% ts_recapitate(Ne = 1000, recombination_rate = 0) %>% ts_simplify()
   table3 <- ts_nodes(ts3)
 
-  suppressWarnings(ts4 <- ts_load(model, file = slim_ts) %>% ts_recapitate(Ne = 1000, recombination_rate = 0) %>% ts_mutate(mutation_rate = 1e-6))
+  suppressWarnings(ts4 <- ts_read(model, file = slim_ts) %>% ts_recapitate(Ne = 1000, recombination_rate = 0) %>% ts_mutate(mutation_rate = 1e-6))
   table4 <- ts_nodes(ts4)
 
   expect_true(ts1$num_individuals == sum(!is.na(unique(table1$ind_id))))
@@ -157,16 +161,16 @@ test_that("extracted individual, node, edge, and mutation counts match the tree
 test_that("extracted individual, node, edge, and mutation counts match the tree sequence (msprime)", {
   # this is not a super useful test as no recapitation or simplification would
   # be performed -- but a good sanity check to enforce that ts1 == ts2 == ts3
-  ts1 <- ts_load(model, file = msprime_ts)
+  ts1 <- ts_read(model, file = msprime_ts)
   table1 <- ts_nodes(ts1)
 
-  suppressWarnings(ts2 <- ts_load(model, file = msprime_ts) %>% ts_recapitate(Ne = 1000, recombination_rate = 0))
+  suppressWarnings(ts2 <- ts_read(model, file = msprime_ts) %>% ts_recapitate(Ne = 1000, recombination_rate = 0))
   table2 <- ts_nodes(ts2)
 
-  suppressWarnings(ts3 <- ts_load(model, file = msprime_ts) %>% ts_recapitate(Ne = 1000, recombination_rate = 0) %>% ts_simplify())
+  suppressWarnings(ts3 <- ts_read(model, file = msprime_ts) %>% ts_recapitate(Ne = 1000, recombination_rate = 0) %>% ts_simplify())
   table3 <- ts_nodes(ts3)
 
-  suppressWarnings(ts4 <- ts_load(model, file = msprime_ts) %>% ts_recapitate(Ne = 1000, recombination_rate = 0) %>% ts_simplify() %>% ts_mutate(mutation_rate = 1e-6))
+  suppressWarnings(ts4 <- ts_read(model, file = msprime_ts) %>% ts_recapitate(Ne = 1000, recombination_rate = 0) %>% ts_simplify() %>% ts_mutate(mutation_rate = 1e-6))
   table4 <- ts_nodes(ts4)
 
   expect_true(ts1$num_individuals == sum(!is.na(unique(table1$ind_id))))
@@ -208,13 +212,13 @@ test_that("extracted individual, node, edge, and mutation counts match the tree
 
 test_that("simplification works only for samples that are really present", {
   msg <- "The following individuals are not present"
-  expect_error(ts_load(model, file = slim_ts) %>% ts_recapitate(Ne = 1, recombination_rate = 0) %>% ts_simplify(simplify_to = "xyz"), msg)
-  expect_error(ts_load(model, file = msprime_ts) %>% ts_simplify(simplify_to = "xyz"), msg)
+  expect_error(ts_read(model, file = slim_ts) %>% ts_recapitate(Ne = 1, recombination_rate = 0) %>% ts_simplify(simplify_to = "xyz"), msg)
+  expect_error(ts_read(model, file = msprime_ts) %>% ts_simplify(simplify_to = "xyz"), msg)
 })
 
 test_that("simplification retains only specified samples (SLiM)", {
   simplify_to <- c("pop1_1", "pop1_2", "pop2_7")
-  ts <- ts_load(model, file = slim_ts) %>%
+  ts <- ts_read(model, file = slim_ts) %>%
     ts_recapitate(Ne = 1, recombination_rate = 0) %>%
     ts_simplify(simplify_to = simplify_to)
   df_samples <- ts_samples(ts) %>% dplyr::arrange(name, time)
@@ -223,7 +227,7 @@ test_that("simplification retains only specified samples (SLiM)", {
   expect_true(all(df_data$time == df_samples$time))
   expect_true(all(df_data$pop == df_samples$pop))
 
-  suppressWarnings(ts2 <- ts_load(model, file = slim_ts) %>%
+  suppressWarnings(ts2 <- ts_read(model, file = slim_ts) %>%
     ts_recapitate(recombination_rate = 0, Ne = 1))
   simplify_to <- sample(ts_samples(ts2)$name, 10)
 
@@ -237,14 +241,14 @@ test_that("simplification retains only specified samples (SLiM)", {
 
 test_that("simplification retains only specified samples (msprime)", {
   simplify_to <- c("pop1_1", "pop1_2", "pop2_7")
-  ts <- ts_load(model, file = msprime_ts) %>% ts_simplify(simplify_to = simplify_to)
+  ts <- ts_read(model, file = msprime_ts) %>% ts_simplify(simplify_to = simplify_to)
   df_samples <- ts_samples(ts) %>% dplyr::arrange(name, time)
   df_data <- ts_nodes(ts) %>% stats::na.omit() %>% dplyr::distinct(name, .keep_all = TRUE) %>% dplyr::arrange(name, time)
   expect_true(all(df_data$name == df_samples$name))
   expect_true(all(df_data$time == df_samples$time))
   expect_true(all(df_data$pop == df_samples$pop))
 
-  suppressWarnings(ts2 <- ts_load(model, file = msprime_ts) %>% ts_recapitate(recombination_rate = 0, Ne = 1))
+  suppressWarnings(ts2 <- ts_read(model, file = msprime_ts) %>% ts_recapitate(recombination_rate = 0, Ne = 1))
   simplify_to <- sample(ts_samples(ts2)$name, 10)
 
   ts2 <- ts_simplify(ts2, simplify_to = simplify_to)
@@ -258,9 +262,9 @@ test_that("simplification retains only specified samples (msprime)", {
 test_that("ts_samples() names match ts_nodes() information (SLiM)", {
   simplify_to <- c("pop1_1", "pop1_2", "pop2_7")
 
-  ts1 <- ts_load(model, file = slim_ts) %>% ts_recapitate(Ne = 1, recombination_rate = 0)
-  ts2 <- ts_load(model, file = slim_ts) %>% ts_recapitate(Ne = 1000, recombination_rate = 0)
-  ts3 <- ts_load(model, file = slim_ts) %>% ts_recapitate(Ne = 1, recombination_rate = 0) %>%
+  ts1 <- ts_read(model, file = slim_ts) %>% ts_recapitate(Ne = 1, recombination_rate = 0)
+  ts2 <- ts_read(model, file = slim_ts) %>% ts_recapitate(Ne = 1000, recombination_rate = 0)
+  ts3 <- ts_read(model, file = slim_ts) %>% ts_recapitate(Ne = 1, recombination_rate = 0) %>%
     ts_simplify(simplify_to = simplify_to)
   simplify_to <- sample(ts_samples(ts1)$name, 10)
   ts4 <- ts_simplify(ts1, simplify_to = simplify_to)
@@ -293,8 +297,8 @@ test_that("ts_samples() names match ts_nodes() information (SLiM)", {
 test_that("ts_samples() names match ts_nodes() information (msprime)", {
   simplify_to <- c("pop1_1", "pop1_2", "pop2_7")
 
-  ts1 <- ts_load(model, file = msprime_ts)
-  ts3 <- ts_load(model, file = msprime_ts) %>% ts_simplify(simplify_to = simplify_to)
+  ts1 <- ts_read(model, file = msprime_ts)
+  ts3 <- ts_read(model, file = msprime_ts) %>% ts_simplify(simplify_to = simplify_to)
   simplify_to <- sample(ts_samples(ts1)$name, 10)
   ts4 <- ts_simplify(ts1, simplify_to = simplify_to)
 
@@ -319,13 +323,13 @@ test_that("ts_samples() names match ts_nodes() information (msprime)", {
 
 test_that("ts_eigenstrat requires recapitated and mutated data (SLiM)", {
   skip_if(Sys.which("qpDstat") == "")
-  ts1 <- ts_load(model, file = slim_ts)
-  ts2 <- ts_load(model, file = slim_ts) %>% ts_recapitate(Ne = 1000, recombination_rate = 0)
-  ts3 <- ts_load(model, file = slim_ts) %>% ts_recapitate(Ne = 1, recombination_rate = 0) %>% ts_simplify(simplify_to = c("pop1_1", "pop1_2"))
-  ts4 <- ts_load(model, file = slim_ts) %>% ts_recapitate(recombination_rate = 0, Ne = 10000) %>%
+  ts1 <- ts_read(model, file = slim_ts)
+  ts2 <- ts_read(model, file = slim_ts) %>% ts_recapitate(Ne = 1000, recombination_rate = 0)
+  ts3 <- ts_read(model, file = slim_ts) %>% ts_recapitate(Ne = 1, recombination_rate = 0) %>% ts_simplify(simplify_to = c("pop1_1", "pop1_2"))
+  ts4 <- ts_read(model, file = slim_ts) %>% ts_recapitate(recombination_rate = 0, Ne = 10000) %>%
     ts_simplify()
   ts5 <- ts_mutate(ts4, mutation_rate = 1e-7)
-  ts6 <- ts_load(model, file = slim_ts) %>% ts_recapitate(recombination_rate = 0, Ne = 10000) %>%
+  ts6 <- ts_read(model, file = slim_ts) %>% ts_recapitate(recombination_rate = 0, Ne = 10000) %>%
     ts_simplify() %>%
     ts_mutate(mutation_rate = 1e-7)
 
@@ -348,11 +352,11 @@ test_that("ts_eigenstrat requires recapitated and mutated data (SLiM)", {
 
 test_that("ts_eigenstrat requires recapitated and mutated data (msprime)", {
   skip_if(Sys.which("qpDstat") == "")
-  ts1 <- ts_load(model, file = msprime_ts)
-  ts3 <- ts_load(model, file = msprime_ts) %>% ts_simplify(simplify_to = c("pop1_1", "pop1_2", "pop2_7"))
-  ts4 <- ts_load(model, file = msprime_ts) %>% ts_simplify()
+  ts1 <- ts_read(model, file = msprime_ts)
+  ts3 <- ts_read(model, file = msprime_ts) %>% ts_simplify(simplify_to = c("pop1_1", "pop1_2", "pop2_7"))
+  ts4 <- ts_read(model, file = msprime_ts) %>% ts_simplify()
   ts5 <- ts_mutate(ts4, mutation_rate = 1e-7)
-  ts6 <- ts_load(model, file = msprime_ts) %>% ts_simplify(simplify_to = c("pop1_1", "pop1_2", "pop2_7")) %>% ts_mutate(mutation_rate = 1e-7)
+  ts6 <- ts_read(model, file = msprime_ts) %>% ts_simplify(simplify_to = c("pop1_1", "pop1_2", "pop2_7")) %>% ts_mutate(mutation_rate = 1e-7)
 
   # this is not supposed to fail (unlike the previous SLiM case) because all
   # msprime sequences are "recapitated" by virtue of beling coalescent!
@@ -372,28 +376,28 @@ test_that("ts_eigenstrat requires recapitated and mutated data (msprime)", {
 })
 
 test_that("ts_mutate cannot be called on an already mutated tree sequence (SLiM)", {
-  ts <- ts_load(model, file = slim_ts)
+  ts <- ts_read(model, file = slim_ts)
   ts_mut <- ts_mutate(ts, mutation_rate = 1e-7)
   expect_error(ts_mutate(ts_mut, mutation_rate = 2e-7),
                "Tree sequence already mutated")
 })
 
 test_that("ts_mutate cannot be called on an already mutated tree sequence (msprime)", {
-  ts <- ts_load(model, file = msprime_ts)
+  ts <- ts_read(model, file = msprime_ts)
   ts_mut <- ts_mutate(ts, mutation_rate = 1e-7)
   expect_error(ts_mutate(ts_mut, mutation_rate = 2e-7),
                "Tree sequence already mutated")
 })
 
 test_that("ts_simplify-ing a non-recapitated tree sequence gives a warning", {
-  ts <- ts_load(model, file = slim_ts)
+  ts <- ts_read(model, file = slim_ts)
   expect_warning(ts_simplify(ts), "Simplifying a non-recapitated tree sequence.")
   expect_silent(ts_simplify(ts, keep_input_roots = TRUE))
 })
 
 test_that("ts_eigenstrat and tsv_cf create correct data (SLiM)", {
   skip_if(Sys.which("qpDstat") == "")
-  ts <- ts_load(model, file = slim_ts) %>% ts_recapitate(recombination_rate = 0, Ne = 10000) %>%
+  ts <- ts_read(model, file = slim_ts) %>% ts_recapitate(recombination_rate = 0, Ne = 10000) %>%
     ts_simplify() %>%
     ts_mutate(mutation_rate = 1e-7)
 
@@ -418,7 +422,7 @@ test_that("ts_eigenstrat and tsv_cf create correct data (SLiM)", {
 
 test_that("ts_eigenstrat and tsv_cf create correct data (msprime)", {
   skip_if(Sys.which("qpDstat") == "")
-  ts <- ts_load(model, file = msprime_ts) %>% ts_mutate(mutation_rate = 1e-7)
+  ts <- ts_read(model, file = msprime_ts) %>% ts_mutate(mutation_rate = 1e-7)
 
   ts_names <- sort(unique(ts_nodes(ts) %>% .$name))
 
@@ -441,7 +445,7 @@ test_that("ts_eigenstrat and tsv_cf create correct data (msprime)", {
 
 test_that("ts_eigenstrat correctly adds an outgroup when instructed (SLiM)", {
   skip_if(Sys.which("qpDstat") == "")
-  ts <- ts_load(model, file = slim_ts) %>% ts_recapitate(recombination_rate = 0, Ne = 10000) %>%
+  ts <- ts_read(model, file = slim_ts) %>% ts_recapitate(recombination_rate = 0, Ne = 10000) %>%
     ts_simplify() %>%
     ts_mutate(mutation_rate = 1e-7)
 
@@ -456,7 +460,7 @@ test_that("ts_eigenstrat correctly adds an outgroup when instructed (SLiM)", {
 
 test_that("ts_eigenstrat correctly adds an outgroup when instructed (msprime)", {
   skip_if(Sys.which("qpDstat") == "")
-  ts <- ts_load(model, file = msprime_ts) %>% ts_mutate(mutation_rate = 1e-7)
+  ts <- ts_read(model, file = msprime_ts) %>% ts_mutate(mutation_rate = 1e-7)
 
   ts_names <- sort(unique(ts_nodes(ts) %>% .$name))
 
@@ -468,19 +472,20 @@ test_that("ts_eigenstrat correctly adds an outgroup when instructed (msprime)",
 })
 
 test_that("slendr metadata is correctly loaded (spatial model without CRS)", {
-  output <- paste0(tempfile(), "spatial_test")
+  output <- normalizePath(paste0(tempfile(), "spatial_test"), winslash = "/", mustWork = FALSE)
 
   burnin_length <- 123
   max_attempts <- 3
-  recomb_rate <- 0.001
-  locations_file <- tempfile(fileext = ".gz")
+  RECOMBINATION_RATE <- 0.001
+  locations_file <- normalizePath(tempfile(fileext = ".gz"), winslash = "/", mustWork = FALSE)
   seed <- 987
   sequence_length <- 999
 
-  ts <- slim(model, sequence_length = sequence_length, recombination_rate = recomb_rate,
+  ts <- slim(model, sequence_length = sequence_length, recombination_rate = RECOMBINATION_RATE,
        locations = locations_file, burnin = burnin_length,
        method = "batch", random_seed = seed, max_attempts = max_attempts,
-       samples = samples, verbose = FALSE, output = output)
+       samples = samples, verbose = FALSE)
+  ts_write(ts, output)
 
   metadata <- ts_metadata(ts)
 
@@ -493,25 +498,26 @@ test_that("slendr metadata is correctly loaded (spatial model without CRS)", {
   args <- metadata$arguments
   expect_equal(args$BURNIN_LENGTH, burnin_length)
   expect_equal(args$MAX_ATTEMPTS, max_attempts)
-  expect_equal(args$RECOMB_RATE, recomb_rate)
+  expect_equal(args$RECOMBINATION_RATE, RECOMBINATION_RATE)
   expect_equal(args$SEED, seed)
   expect_equal(args$SEQUENCE_LENGTH, sequence_length)
 })
 
 test_that("slendr metadata is correctly loaded (non-spatial SLiM model)", {
-  output <- paste0(tempfile(), "non-spatial_SLiM_test")
+  output <- normalizePath(paste0(tempfile(), "non-spatial_SLiM_test"), winslash = "/", mustWork = FALSE)
 
   burnin_length <- 123
-  recomb_rate <- 0.001
-  locations_file <- tempfile(fileext = ".gz")
+  RECOMBINATION_RATE <- 0.001
+  locations_file <- normalizePath(tempfile(fileext = ".gz"), winslash = "/", mustWork = FALSE)
   seed <- 987
   sequence_length <- 999
   spatial <- FALSE
 
-  ts <- slim(model, sequence_length = sequence_length, recombination_rate = recomb_rate,
+  ts <- slim(model, sequence_length = sequence_length, recombination_rate = RECOMBINATION_RATE,
        locations = locations_file, burnin = burnin_length,
        method = "batch", random_seed = seed,
-       samples = samples, verbose = FALSE, spatial = spatial, output = output)
+       samples = samples, verbose = FALSE, spatial = spatial)
+  ts_write(ts, output)
 
   metadata <- ts_metadata(ts)
 
@@ -521,7 +527,7 @@ test_that("slendr metadata is correctly loaded (non-spatial SLiM model)", {
 
   args <- metadata$arguments
   expect_equal(args$BURNIN_LENGTH, burnin_length)
-  expect_equal(args$RECOMB_RATE, recomb_rate)
+  expect_equal(args$RECOMBINATION_RATE, RECOMBINATION_RATE)
   expect_equal(args$SEED, seed)
   expect_equal(args$SEQUENCE_LENGTH, sequence_length)
 })
@@ -530,13 +536,14 @@ test_that("slendr metadata is correctly loaded (non-spatial msprime model)", {
   output <- paste0(tempfile(), "non-spatial_msprime_test")
 
   burnin_length <- 123
-  recomb_rate <- 0.001
+  RECOMBINATION_RATE <- 0.001
   seed <- 987
   sequence_length <- 999
   spatial <- FALSE
 
-  ts <- msprime(model, sequence_length = sequence_length, recombination_rate = recomb_rate,
-       random_seed = seed, samples = samples, verbose = FALSE, output = output)
+  ts <- msprime(model, sequence_length = sequence_length, recombination_rate = RECOMBINATION_RATE,
+       random_seed = seed, samples = samples, verbose = FALSE)
+  ts_write(ts, output)
   metadata <- ts_metadata(ts)
 
   expect_true(gsub("slendr_", "", metadata$version) == packageVersion("slendr"))
@@ -544,34 +551,36 @@ test_that("slendr metadata is correctly loaded (non-spatial msprime model)", {
   expect_true(metadata$description == desc)
 
   args <- metadata$arguments
-  expect_equal(args$RECOMB_RATE, recomb_rate)
+  expect_equal(args$RECOMBINATION_RATE, RECOMBINATION_RATE)
   expect_equal(args$SEED, seed)
   expect_equal(args$SEQUENCE_LENGTH, sequence_length)
 })
 
-test_that("ts_mutate and mutation through ts_load give the same result (SLiM)", {
-  ts <- ts_load(model, file = slim_ts) %>%
+test_that("ts_mutate and mutation through ts_read give the same result (SLiM)", {
+  ts <- ts_read(model, file = slim_ts) %>%
     ts_recapitate(random_seed = 123, recombination_rate = 0, Ne = 100) %>% ts_simplify()
   ts_mut1 <- ts_mutate(ts, mutation_rate = 1e-7, random_seed = 123)
-  ts_mut2 <- ts_load(model, file = slim_ts) %>% ts_recapitate(random_seed = 123, recombination_rate = 0, Ne = 100) %>% ts_simplify() %>% ts_mutate(mutation_rate = 1e-7, random_seed = 123)
+  ts_mut2 <- ts_read(model, file = slim_ts) %>% ts_recapitate(random_seed = 123, recombination_rate = 0, Ne = 100) %>% ts_simplify() %>% ts_mutate(mutation_rate = 1e-7, random_seed = 123)
   expect_equal(suppressMessages(ts_genotypes(ts_mut1)),
                suppressMessages(ts_genotypes(ts_mut2)))
 })
 
-test_that("ts_mutate and mutation through ts_load give the same result (msprime)", {
-  ts <- ts_load(model, file = msprime_ts)
+test_that("ts_mutate and mutation through ts_read give the same result (msprime)", {
+  ts <- ts_read(model, file = msprime_ts)
   ts_mut1 <- ts_mutate(ts, mutation_rate = 1e-7, random_seed = 123)
-  ts_mut2 <- ts_load(msprime_ts, model) %>% ts_mutate(mutation_rate = 1e-7, random_seed = 123)
+  ts_mut2 <- ts_read(msprime_ts, model) %>% ts_mutate(mutation_rate = 1e-7, random_seed = 123)
   expect_equal(suppressMessages(ts_genotypes(ts_mut1)),
                suppressMessages(ts_genotypes(ts_mut2)))
 })
 
 test_that("ts_mutate correctly specifies the SLiM mutation type", {
-  ts <- ts_load(slim_ts, model) %>%
+  ts <- ts_read(slim_ts, model) %>%
     ts_recapitate(random_seed = 123, recombination_rate = 0, Ne = 100) %>%
     ts_simplify()
   ts_mut1 <- ts_mutate(ts, mutation_rate = 1e-7, random_seed = 123)
-  ts_mut2 <- ts_mutate(ts, mutation_rate = 1e-7, random_seed = 123, mut_type = 123456789)
+  msprime_module <- reticulate::import("msprime")
+  ts_mut2 <- ts_mutate(ts, mutation_rate = 1e-7, random_seed = 123,
+                       mutation_model = msprime_module$SLiMMutationModel(123456789L))
 
   get_mut_type <- function(m) {
     mut_metadata <- m$metadata$mutation_list
@@ -630,40 +639,40 @@ test_that("metadata is the same for SLiM and msprime conditional on a model", {
     schedule_sampling(model, times = 300, list(p1, 10), list(p2, 10))
   )
 
-  slim_ts <- file.path(model_dir, "output_slim.trees")
-  msprime_ts <- file.path(model_dir, "msprime_output.trees")
+  slim_ts <- normalizePath(file.path(model_dir, "output_slim.trees"), winslash = "/", mustWork = FALSE)
+  msprime_ts <- normalizePath(file.path(model_dir, "msprime_output.trees"), winslash = "/", mustWork = FALSE)
 
   slim(model, sequence_length = 100000, recombination_rate = 0,
        locations = locations_file, burnin = 10,
        method = "batch", random_seed = 314159,
-       samples = samples, verbose = FALSE, output = slim_ts)
+       samples = samples, verbose = FALSE) %>% ts_write(slim_ts)
 
-  msprime(model, sequence_length = 100000, recombination_rate = 0, output = msprime_ts,
-          random_seed = 314159, samples = samples, verbose = FALSE)
+  msprime(model, sequence_length = 100000, recombination_rate = 0,
+          random_seed = 314159, samples = samples, verbose = FALSE) %>% ts_write(msprime_ts)
 
   simplify_to <- c("pop1_1", "pop1_2", "pop1_17")
 
-  sts1 <- ts_load(model = model, file = slim_ts)
-  sts2 <- ts_load(model = model, file = slim_ts) %>%
+  sts1 <- ts_read(model = model, file = slim_ts)
+  sts2 <- ts_read(model = model, file = slim_ts) %>%
     ts_recapitate(Ne = 1000, recombination_rate = 0)
-  sts3 <- ts_load(model = model, file = slim_ts) %>%
+  sts3 <- ts_read(model = model, file = slim_ts) %>%
     ts_recapitate(Ne = 1, recombination_rate = 0) %>%
     ts_simplify(simplify_to = simplify_to)
-  sts4 <- ts_load(model = model, file = slim_ts) %>%
+  sts4 <- ts_read(model = model, file = slim_ts) %>%
     ts_recapitate(recombination_rate = 0, Ne = 10000) %>%
     ts_simplify()
   sts5 <- ts_mutate(sts4, mutation_rate = 1e-7)
-  sts6 <- ts_load(model = model, file = slim_ts) %>%
+  sts6 <- ts_read(model = model, file = slim_ts) %>%
     ts_recapitate(recombination_rate = 0, Ne = 10000) %>%
     ts_simplify() %>%
     ts_mutate(mutation_rate = 1e-7)
 
-  mts1 <- ts_load(model = model, file = msprime_ts)
-  mts2 <- ts_load(model = model, file = msprime_ts)
-  mts3 <- ts_load(model = model, file = msprime_ts) %>% ts_simplify(simplify_to = simplify_to)
-  suppressWarnings(mts4 <- ts_load(model = model, file = msprime_ts) %>% ts_simplify())
+  mts1 <- ts_read(model = model, file = msprime_ts)
+  mts2 <- ts_read(model = model, file = msprime_ts)
+  mts3 <- ts_read(model = model, file = msprime_ts) %>% ts_simplify(simplify_to = simplify_to)
+  suppressWarnings(mts4 <- ts_read(model = model, file = msprime_ts) %>% ts_simplify())
   mts5 <- ts_mutate(mts4, mutation_rate = 1e-7)
-  mts6 <- ts_load(model = model, file = msprime_ts) %>% ts_mutate(mutation_rate = 1e-7)
+  mts6 <- ts_read(model = model, file = msprime_ts) %>% ts_mutate(mutation_rate = 1e-7)
 
   expect_equal(ts_samples(sts1), ts_samples(mts1))
   expect_equal(ts_samples(sts2), ts_samples(mts2))
@@ -701,7 +710,7 @@ test_that("metadata is the same for SLiM and msprime conditional on a model", {
 })
 
 test_that("all names of individuals must be present in the tree sequence", {
-  ts <- ts_load(file = msprime_ts, model = model)
+  ts <- ts_read(file = msprime_ts, model = model)
   expect_error(ts_diversity(ts, c("p1_1", "p2_2")), "Not all individual names")
   expect_s3_class(ts_diversity(ts, c("pop1_1", "pop2_2")), "data.frame")
 })
@@ -711,7 +720,7 @@ test_that("all names of individuals must be present in the tree sequence", {
 # test-ts-pure-spatial.R and test-ts-pure-nonspatial.R)
 
 test_that("ts_ibd() on spatial SLiM/slendr tree sequences works properly (no CRS)", {
-  suppressWarnings(ts_slim <- ts_load(model, file = slim_ts) %>% ts_simplify())
+  suppressWarnings(ts_slim <- ts_read(model, file = slim_ts) %>% ts_simplify())
 
   suppressWarnings(slim_ibd_sf <- ts_ibd(ts_slim, coordinates = TRUE))
   suppressWarnings(slim_ibd_nosf <- ts_ibd(ts_slim, coordinates = TRUE, sf = FALSE))
@@ -735,7 +744,7 @@ test_that("ts_ibd() on spatial SLiM/slendr tree sequences works properly (no CRS
 })
 
 test_that("ts_ibd() on msprime/slendr tree sequences works properly", {
-  ts_msprime <- ts_load(model, file = msprime_ts)
+  ts_msprime <- ts_read(model, file = msprime_ts)
 
   suppressWarnings(msprime_ibd_sf <- ts_ibd(ts_msprime, coordinates = TRUE))
   suppressWarnings(msprime_ibd_nosf <- ts_ibd(ts_msprime, coordinates = TRUE, sf = FALSE))
@@ -781,8 +790,8 @@ test_that("ts_ibd() on spatial SLiM/slendr tree sequences works properly (with C
                as.data.frame(ibd_nosf)))
 })
 
-test_that("ts_load tracks a path to the tree-sequence file if loaded from a file", {
-  ts1 <- ts_load(slim_ts, model)
+test_that("ts_read tracks a path to the tree-sequence file if loaded from a file", {
+  ts1 <- ts_read(slim_ts, model)
   ts2 <- ts_recapitate(ts1, recombination_rate = 0, Ne = 100)
   ts3 <- ts_simplify(ts2)
   ts4 <- ts_mutate(ts1, 1e-8)
@@ -793,7 +802,7 @@ test_that("ts_load tracks a path to the tree-sequence file if loaded from a file
   expect_true(attr(ts4, "path") == normalizePath(slim_ts))
 })
 
-test_that("ts_load does not track any file path if a tree sequence is directly loaded", {
+test_that("ts_read does not track any file path if a tree sequence is directly loaded", {
   nonser_model <- model
   nonser_model$path <- NULL
 
@@ -813,8 +822,8 @@ test_that("ts_load does not track any file path if a tree sequence is directly l
 #------------------------------------------------------------------
 # testing names extraction
 
-ts_msprime <- ts_load(msprime_ts, model)
-ts_slim <- ts_load(slim_ts, model)
+ts_msprime <- ts_read(msprime_ts, model)
+ts_slim <- ts_read(slim_ts, model)
 
 test_that("ts_names(ts) returns a simple character vector", {
   expect_type(ts_names(ts_msprime), "character")
